@@ -11,8 +11,10 @@ from magicapi.Models.task_executor import save_tasks
 import os
 import sentry_sdk
 
+dsn = os.getenv("SENTRY_DSN")
+print("DSN in middleware", dsn)
 sentry_sdk.init(
-    os.getenv("SENTRY_DSN"),
+    dsn,
     # Set traces_sample_rate to 1.0 to capture 100%
     # of transactions for performance monitoring.
     # We recommend adjusting this value in production.
